import { Updater } from './utils';
import { Query } from './query';
import { QueryConfig, QueryFunction, QueryKey, ReactQueryConfig, TypedQueryFunction, TypedQueryFunctionArgs } from './types';
interface QueryCacheConfig {
    frozen?: boolean;
    defaultConfig?: ReactQueryConfig;
}
interface ClearOptions {
    notify?: boolean;
}
interface PrefetchQueryOptions {
    force?: boolean;
    throwOnError?: boolean;
}
interface InvalidateQueriesOptions extends QueryPredicateOptions {
    refetchActive?: boolean;
    refetchInactive?: boolean;
    throwOnError?: boolean;
}
interface QueryPredicateOptions {
    exact?: boolean;
}
declare type QueryPredicate = QueryKey | QueryPredicateFn | true;
declare type QueryPredicateFn = (query: Query<unknown, unknown>) => boolean;
export interface PrefetchQueryObjectConfig<TResult, TError> {
    queryKey: QueryKey;
    queryFn?: QueryFunction<TResult>;
    config?: QueryConfig<TResult, TError>;
    options?: PrefetchQueryOptions;
}
interface QueryHashMap {
    [hash: string]: Query<any, any>;
}
declare type QueryCacheListener = (cache: QueryCache, query?: Query<unknown, unknown>) => void;
export declare class QueryCache {
    queries: QueryHashMap;
    isFetching: number;
    private config;
    private globalListeners;
    constructor(config?: QueryCacheConfig);
    private notifyGlobalListeners;
    getDefaultConfig(): ReactQueryConfig<unknown, unknown> | undefined;
    getDefaultedQueryConfig<TResult, TError>(config?: QueryConfig<TResult, TError>): QueryConfig<TResult, TError>;
    subscribe(listener: QueryCacheListener): () => void;
    clear(options?: ClearOptions): void;
    getQueries<TResult = unknown, TError = unknown>(predicate: QueryPredicate, options?: QueryPredicateOptions): Query<TResult, TError>[];
    getQuery<TResult, TError = unknown>(predicate: QueryPredicate): Query<TResult, TError> | undefined;
    getQueryData<TResult>(predicate: QueryPredicate): TResult | undefined;
    removeQueries(predicate: QueryPredicate, options?: QueryPredicateOptions): void;
    cancelQueries(predicate: QueryPredicate, options?: QueryPredicateOptions): void;
    invalidateQueries(predicate: QueryPredicate, options?: InvalidateQueriesOptions): Promise<void>;
    resetErrorBoundaries(): void;
    buildQuery<TResult, TError = unknown>(userQueryKey: QueryKey, queryConfig?: QueryConfig<TResult, TError>): Query<TResult, TError>;
    prefetchQuery<TResult = unknown, TError = unknown>(queryKey: QueryKey, options?: PrefetchQueryOptions): Promise<TResult | undefined>;
    prefetchQuery<TResult, TError, TArgs extends TypedQueryFunctionArgs>(queryKey: QueryKey, queryFn: TypedQueryFunction<TResult, TArgs>, options?: PrefetchQueryOptions): Promise<TResult | undefined>;
    prefetchQuery<TResult = unknown, TError = unknown>(queryKey: QueryKey, queryFn: QueryFunction<TResult>, options?: PrefetchQueryOptions): Promise<TResult | undefined>;
    prefetchQuery<TResult, TError, TArgs extends TypedQueryFunctionArgs>(queryKey: QueryKey, queryFn: TypedQueryFunction<TResult, TArgs>, queryConfig: QueryConfig<TResult, TError>, options?: PrefetchQueryOptions): Promise<TResult | undefined>;
    prefetchQuery<TResult = unknown, TError = unknown>(queryKey: QueryKey, queryFn: QueryFunction<TResult>, queryConfig: QueryConfig<TResult, TError>, options?: PrefetchQueryOptions): Promise<TResult | undefined>;
    prefetchQuery<TResult = unknown, TError = unknown>(config: PrefetchQueryObjectConfig<TResult, TError>): Promise<TResult | undefined>;
    setQueryData<TResult, TError = unknown>(queryKey: QueryKey, updater: Updater<TResult | undefined, TResult>, config?: QueryConfig<TResult, TError>): void;
}
declare const defaultQueryCache: QueryCache;
export { defaultQueryCache as queryCache };
export declare const queryCaches: QueryCache[];
export declare function makeQueryCache(config?: QueryCacheConfig): QueryCache;
